# [1.7.13](https://github.com/seriaati/genshin.py/compare/v1.7.12..v1.7.13) - 2025-06-15

## Bug Fixes

- Fix docstring not in impereative mood - ([5b9ca6b](https://github.com/seriaati/genshin.py/commit/5b9ca6b24ce736e8a4db225dc23b04a11dc324c8))
- Update emoji extension - ([8d94053](https://github.com/seriaati/genshin.py/commit/8d94053fd6c650a9bfb2bcc437464531190113d2))
- Fix not returning correct models in get_starrail_lineups - ([e46d681](https://github.com/seriaati/genshin.py/commit/e46d681bf6b02e2aff929a21ab98497c3f905082))
- Fix hsr lineup tests - ([5ae1adc](https://github.com/seriaati/genshin.py/commit/5ae1adc5c7d0b83ceb902f23a578439096b51a0a))
- Replace 'ashleney' with 'seriaati' - ([8399d5a](https://github.com/seriaati/genshin.py/commit/8399d5ace8630aed5bbe2dfbf634dedda73eec0a))

## Documentation

- Change "thesadru" to "ashleney" ([#256](https://github.com/seriaati/genshin.py/issues/256)) - ([fe5b300](https://github.com/seriaati/genshin.py/commit/fe5b300b6905f43461165d350108638360c6e20c))
- Add documentation for hsr_lineup - ([bdbfcf6](https://github.com/seriaati/genshin.py/commit/bdbfcf60feb2f685905e325141aae13c47dd4163))
- Add hsr_lineup.md to nav - ([cf5a165](https://github.com/seriaati/genshin.py/commit/cf5a16526927ad6a25b0449e3aba22329ccdeff8))
- Fix style issue with README - ([d7b1f7b](https://github.com/seriaati/genshin.py/commit/d7b1f7b518f7c5f05f2b03d229de9fc9ae94960d))
- Remove contributing & licensing sections in index.md - ([534c565](https://github.com/seriaati/genshin.py/commit/534c565b0b8e41384dbb0a28a756949fa58570c2))
- Use codeblocks for params - ([e62595c](https://github.com/seriaati/genshin.py/commit/e62595c651afb5fbac5f2dc4abba077658a86021))
- Fix wording - ([170e81e](https://github.com/seriaati/genshin.py/commit/170e81eb3460cd650caabefdafedbb252d4157b3))
- Add project transfer notice to README - ([14ee739](https://github.com/seriaati/genshin.py/commit/14ee73983c1d544de92a502f326c3b18e8f0c38d))

## Features

- Add HSR Lineup Simulator ([#257](https://github.com/seriaati/genshin.py/issues/257)) - ([9503d81](https://github.com/seriaati/genshin.py/commit/9503d81f59657737f20b6327c41daa93b94b1bff))
- Add 'order' param to get_starrail_lineups - ([6698851](https://github.com/seriaati/genshin.py/commit/6698851a4bb1a10b4014f968e5725ce0c15946bd))
- Support ZZZ 2.0 new stats - ([a8bd1be](https://github.com/seriaati/genshin.py/commit/a8bd1beb5fd52b7f684afda71c06cc51e901db80))
- Add new error codes - ([c99da0b](https://github.com/seriaati/genshin.py/commit/c99da0b80c8542206ab7a59cb7d4b9d77f0bdc23))
- Add exception class for RedeemGameLevelTooLow - ([ebc0daa](https://github.com/seriaati/genshin.py/commit/ebc0daaf540ca34d4f520796292b82af7cd14e04))

## Improvements

- Use enum for hsr lineup game mode - ([3d649d2](https://github.com/seriaati/genshin.py/commit/3d649d2fd3a817c788f56cd7b714519d4537b3ea))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#258](https://github.com/seriaati/genshin.py/issues/258)) - ([77f543f](https://github.com/seriaati/genshin.py/commit/77f543f9c6f9683a70fc9945784d6a899b032730))

